@@ -1,5 +1,4 @@
 import functools
-import sys
 
 from .transaction import current_transaction
 from ..common.object_wrapper import FunctionWrapper, wrap_object
@@ -14,39 +13,14 @@ class ErrorTrace(object):
         return self
 
     def __exit__(self, exc, value, tb):
-        if self._transaction is None:
-            return
-
         if exc is None or value is None or tb is None:
             return
 
-        module = value.__class__.__module__
-        name = value.__class__.__name__
-
-        # We need to check for module.name and module:name.
-        # Originally we used module.class but that was
-        # inconsistent with everything else which used
-        # module:name. So changed to use ':' as separator, but
-        # for backward compatability need to support '.' as
-        # separator for time being.
-
-        if module:
-            path = '%s:%s' % (module, name)
-        else:
-            path = name
-
-        if self._ignore_errors and path in self._ignore_errors:
+        if self._transaction is None:
             return
 
-        if module:
-            path = '%s.%s' % (module, name)
-        else:
-            path = name
-
-        if self._ignore_errors and path in self._ignore_errors:
-            return
-
-        self._transaction.record_exception(exc, value, tb)
+        self._transaction.record_exception(exc=exc, value=value, tb=tb,
+                ignore_errors=self._ignore_errors)
 
 def ErrorTraceWrapper(wrapped, ignore_errors=None):
 
